jQuery(function($) {
    "use strict";
    var SLZ = window.SLZ || {};
    var AudioContext = window.AudioContext || window.webkitAudioContext;
    var player, source, audioCtx;
    SLZ.audio_multiplayer = function() {
        $('audio.sc-audio-default').mediaelementplayer();
        $('.sc_audio audio.slz-playlist-container').each(function() {
            player = new MediaElementPlayer( $(this),
                {
                    audioWidth: '100%',
                    audioHeight: '100%',
                    startVolume: 0.5,
                    loop: true,
                    shuffle: true,
                    playlist: true,
                    playlistposition: 'bottom',
                    features: ['playlistfeature', 'prevtrack', 'playpause', 'nexttrack', 'loop', 'shuffle', 'current', 'progress', 'duration', 'volume'],
                }
            );
            // Switch Position Mejs Controls and Mejs Layers
            $(this).parents('.sc_audio').find('.mejs-controls').insertBefore( $(this).parents('.sc_audio').find('.mejs-layers') );
            // Custom Scrollbar List Item
            $(this).parents('.sc_audio').find('.mejs-playlist ul.mejs').mCustomScrollbar({
                axis: 'y',
                theme: 'dark'
            });
        });
    };
    SLZ.oscilloscope = function() {
        if ($('.sc_audio canvas.oscilloscope').length > 0) {
            var load_volumn = function(_this) {
                audioCtx = new AudioContext();
                var oscillator = audioCtx.createOscillator();
                var gainNode = audioCtx.createGain();
                var analyser = audioCtx.createAnalyser();
                var distortion = audioCtx.createWaveShaper();
                var biquadFilter = audioCtx.createBiquadFilter();
                var convolver = audioCtx.createConvolver();
                var canvas = _this.find('canvas')[0];
                // var myMediaElement = $('#current-audio');
                var myMediaElement = _this.find('audio.current-audio')[0];
                source = audioCtx.createMediaElementSource(myMediaElement);
                source.connect(gainNode);
                source.connect(analyser);
                analyser.connect(distortion);
                distortion.connect(biquadFilter);
                biquadFilter.connect(convolver);
                convolver.connect(gainNode);
                oscillator.connect(gainNode);
                gainNode.connect(audioCtx.destination);
                // Get a canvas defined with ID "oscilloscope"
                var canvasCtx = canvas.getContext("2d");
                var intendedWidth = document.querySelector('.oscilloscope-wrapper').clientWidth;
                canvas.setAttribute('width',intendedWidth);
                var drawVisual;
                var canvasWidth = canvas.width;
                var canvasHeight = canvas.height;
                analyser.fftSize = 256;
                var bufferLength = analyser.frequencyBinCount;
                var dataArray = new Uint8Array(bufferLength);
                canvasCtx.clearRect(0, 0, canvasWidth, canvasHeight);
                function draw() {
                    drawVisual = requestAnimationFrame(draw);
                    analyser.getByteFrequencyData(dataArray);
                    canvasCtx.fillStyle = '#f7f7f7';
                    canvasCtx.fillRect(0, 0, canvasWidth, canvasHeight);
                    var barWidth = (canvasWidth / bufferLength) * 2.5;
                    var barHeight;
                    var x = 0;
                    for(var i = 0; i < bufferLength; i++) {
                        canvasCtx.fillStyle = '#ebebeb';
                        canvasCtx.fillRect(x, 0, barWidth / 1.2, canvasHeight);
                        x += barWidth + 1;
                    }
                    x = 0;
                    for(var i = 0; i < bufferLength; i++) {
                        barHeight = dataArray[i];
                        canvasCtx.fillStyle = 'rgb(' + ( barHeight + -10 ) + ', 46, 178)';
                        canvasCtx.fillRect(x, canvasHeight - barHeight / 2, barWidth / 1.2, barHeight / 2);
                        x += barWidth + 1;
                    }
                };
                draw();
            }
            var sc_audio = $('.sc_audio');
            for(var i=0; i<sc_audio.length; i++) {
                var c_canvas = $(sc_audio[i]);
                if (c_canvas.find('canvas.oscilloscope').length > 0) {
                    load_volumn(c_canvas);
                }
            }
        }
    }

    SLZ.slz_portfolio_submit_ajax = function () {
        if ($('.slz-project-carousel.layout-2 .slz-carousel .item').length > 0) {
            $(document).on('click', '.slz-project-carousel.layout-2 .slz-carousel .item', function () {
                if (source) {
                    source.disconnect();
                    source = null;
                    if (audioCtx) {
                        audioCtx.close();
                        audioCtx = null;
                    }
                }
                var elm = $(this);

                var post_id = elm.data('post-id');
                var id_img_hover = elm.find('.slz-carousel-content').data('id-img-hover');

                var data = {
                    "post_id": post_id,
                    "id_img_hover": id_img_hover
                };

                $.fn.Form.ajax(['portfolio', 'ajax_get_content_playlist'], [data], function (res) {
                    res = jQuery.parseJSON(res);
                    if (res.success) {
                        elm.parents('.slz-project-carousel').find('.slz-carousel-content').html(res.image_content + res.content);
                        SLZ.audio_multiplayer();
                        SLZ.diskRotate();
                        SLZ.oscilloscope();
                    }
                });
            });
        }
    };

    SLZ.diskRotate = function () {
        // Optimize Rotate Disc
        if ($('.main-audio').length) {
            $('.main-audio')
                .on('play', function () {
                    // layout 2
                    $(this).parents('.slz-project-carousel.layout-2').find('.block-img').removeClass('cont-animation');
                    $(this).parents('.slz-project-carousel.layout-2').find('.block-img').toggleClass('cont-animation');
                    // layout 3
                    $(this).parents('.slick-slide').find('.block-img').removeClass('cont-animation');
                    $(this).parents('.slick-slide').find('.block-img').toggleClass('cont-animation');
                })
                .on('pause', function () {
                    // layout 2
                    $(this).parents('.slz-project-carousel.layout-2').find('.block-img').removeClass('cont-animation');
                    // layout 3
                    $(this).parents('.slick-slide').find('.block-img').removeClass('cont-animation');
                });
        }
    };

    $(document).ready(function() {
        SLZ.audio_multiplayer();
        SLZ.diskRotate();
        SLZ.slz_portfolio_submit_ajax();
        SLZ.oscilloscope();
    });

    $(window).on('load',function() {})
});